import pandas as pd

def createDataframe(csv_file):
    """
    createDataframe() converts a website downloads csv to a dataframe
    The function drops duplicates and concats the meta data to the textcolumn so we can
    make shure that there is at least a bit of text even if the crawler didn't catch any text
    :param csv_file:
    :return: dataframe
    """
    df = pd.read_csv(csv_file, encoding='iso-8859-1', delimiter=',')
    df.columns = ['0', '1', '2', '3', '4' ,'5', '6', '7']
    df.drop_duplicates(['3'], inplace=True)
    df['7'] = '"' + df['7'].astype(str) + '"'
    df = df.dropna(subset=['5'])
    df['5'] = '"""' + df['5'].astype(str) + df['7'].astype(str) + '"""'
    return df

###################  TEST   ########################
# file = "./testfiles/website_downloads_cleaned_klein.csv"
# print(createDataframe(file))
####################################################


def getDailySentimentOverview(feature_list):
    """
    getDailySentimentOverview() gets the mean of sentiment1 and sentiment2
    per day based on all articles
    :param feature_list
    :return: list of mean sentiment1 and sentiment2 per day
    """
    sen1 = 0.0
    sen2 = 0
    daily_sen_overview = []
    for elem in feature_list:
        sen1 += elem[0]
        sen2 += elem[1]
    daily_sen_overview.append((sen1 / len(feature_list)))
    daily_sen_overview.append((sen2 / len(feature_list)))
    return daily_sen_overview


def getArticlesWithSuicide(list):
    # Create a list of lists with features about the articles where suicide keyword value is 1
    article_list = []
    for i in list:
        j = i[2]
        if j[0] == 1:
            article_list.append(i)
    return article_list


def calcColorValue(dailyfeature, suicide_articles):
    """
    Calculates the color value based on the mean sentiment of the day and if there
    was mentioned a suicide
    :param dailyfeature:
    :param suicide_articles:
    :return: value to select the right color
    """
    sen = (dailyfeature[0] + dailyfeature[1])/2
    if (sen > 50 and not suicide_articles):
        return 1
    elif ((suicide_articles) or (sen < 10)):
        return 3
    else: return 2