import glob
import os
from nltk.classify import NaiveBayesClassifier
import helpers

# directories of files for sentiment analysis
import sen1_w_dict

neg_path = "./Sentiment/negative_texte/"
pos_path = "./Sentiment/positive_texte/"

# files containing wicipedia articles with negative and positive topics
neg_files = glob.glob(os.path.join(neg_path, "*.txt"))
pos_files = glob.glob(os.path.join(pos_path, "*.txt"))

def getDictionary(words):
    """
    create dictionary for Bayes Classifier
    :param words
    :return: dict
    """
    useful_words = sen1_w_dict.getFilteredTokens(words)
    my_dict = dict([(word, True) for word in useful_words])
    return my_dict
 
def getWordList(files, classification):
    """
    getWordList() returns a list of strings linked with their classification ("lucky", "positive")
    :param files: files containing collected text
    :param classification: e.g. positive, negative, topic
    :return: textlist
    """
    textlist = []
    for file in files:
        with open (file, encoding="utf8") as this_file:
            text = this_file.read()
            textlist.append((getDictionary(text), classification))
    return textlist


def classification(elem):
    """
    classification() uses a NaiveBayesClassifier to classify a text based on the
    training data
    :param elem: elem[5] = article text
    :return: sent_value: 0 = negative, 100 = positive
    """
    neg_texts = getWordList(neg_files, "negative")
    pos_texts = getWordList(pos_files, "positive")
    train_set = neg_texts + pos_texts
    classifier = NaiveBayesClassifier.train(train_set)

    if isinstance(elem[5], str):
        words = getDictionary(elem[5])
        sent_value = 0
        result = classifier.classify(words)
    if (result == "positive"):
        sent_value = 1
    return sent_value * 100


###################  TEST   ########################
#csv = "./testfiles/website_downloads_cleaned_klein.csv"
#datalist = helpers.createDataframe(csv).values.tolist()
#test_elem = datalist[27]
#
#print(classification(test_elem))
#print(test_elem[5])
####################################################
